@@ -1,4 +1,4 @@
-package Pcore::Selenium v0.7.3;
+package Pcore::Selenium v0.8.0;
 
 use Pcore -dist, -class;
 
@@ -14,6 +14,9 @@ Pcore::Selenium
 
 =head1 SYNOPSIS
 
+    # create handle
+    my $h = Pcore::Handle->new('selenium://127.0.0.1:4444');
+
 =head1 DESCRIPTION
 
 =head1 SEE ALSO
